==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/SelectedValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedValueChangedEventArgsDescription } from "./SelectedValueChangedEventArgsDescription";
/**
 * @hidden
 */
var SelectedValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SelectedValueChangedEventArgsDescriptionMetadata, _super);
    function SelectedValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SelectedValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (SelectedValueChangedEventArgsDescriptionMetadata.a == null) {
            SelectedValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SelectedValueChangedEventArgsDescriptionMetadata.c(SelectedValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(SelectedValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(SelectedValueChangedEventArgsDescriptionMetadata.a);
    };
    SelectedValueChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("OldValue", "Date");
        a.item("NewValue", "Date");
    };
    SelectedValueChangedEventArgsDescriptionMetadata.d = function (a) {
        SelectedValueChangedEventArgsDescriptionMetadata.b(a);
        a.ac("SelectedValueChangedEventArgs", function () { return new SelectedValueChangedEventArgsDescription(); });
        a.ab("SelectedValueChangedEventArgs", SelectedValueChangedEventArgsDescriptionMetadata.a);
    };
    SelectedValueChangedEventArgsDescriptionMetadata.$t = markType(SelectedValueChangedEventArgsDescriptionMetadata, 'SelectedValueChangedEventArgsDescriptionMetadata');
    SelectedValueChangedEventArgsDescriptionMetadata.a = null;
    return SelectedValueChangedEventArgsDescriptionMetadata;
}(Base));
export { SelectedValueChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/SelectedValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedValueChangedEventArgsDescription } from "./SelectedValueChangedEventArgsDescription";
/**
 * @hidden
 */
var SelectedValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SelectedValueChangedEventArgsDescriptionMetadata, _super);
    function SelectedValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SelectedValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (SelectedValueChangedEventArgsDescriptionMetadata.a == null) {
            SelectedValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SelectedValueChangedEventArgsDescriptionMetadata.c(SelectedValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(SelectedValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(SelectedValueChangedEventArgsDescriptionMetadata.a);
    };
    SelectedValueChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("OldValue", "Date");
        a.item("NewValue", "Date");
    };
    SelectedValueChangedEventArgsDescriptionMetadata.d = function (a) {
        SelectedValueChangedEventArgsDescriptionMetadata.b(a);
        a.ae("SelectedValueChangedEventArgs", function () { return new SelectedValueChangedEventArgsDescription(); });
        a.ad("SelectedValueChangedEventArgs", SelectedValueChangedEventArgsDescriptionMetadata.a);
    };
    SelectedValueChangedEventArgsDescriptionMetadata.$t = markType(SelectedValueChangedEventArgsDescriptionMetadata, 'SelectedValueChangedEventArgsDescriptionMetadata');
    SelectedValueChangedEventArgsDescriptionMetadata.a = null;
    return SelectedValueChangedEventArgsDescriptionMetadata;
}(Base));
export { SelectedValueChangedEventArgsDescriptionMetadata };
